/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder; 

import org.gjt.sp.jedit.View;
import org.gjt.sp.util.Log;

public class Config {

    private View                        view        = null;
    private boolean                     holded      = false;
    private Orientation                 orientation = null;
    private PluginHolderEntry           entry       = null;
    /**
    Construct a new PluginHolderConfig.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Config.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    Config( View view, 
            boolean holded, 
            PluginHolderEntry entry, 
            Orientation orientation ) {

        if ( view == null || entry == null || orientation == null ) {
            throw new IllegalArgumentException("no arguments may be null");
        }
                            
        this.view = view;
        this.holded = holded;
        this.entry = entry;
        this.orientation = orientation;

    }

    /**
    Returns the view that this plugin is running under
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Config.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public View getView() {
        return this.view;        
    }


    /**
    Defines if this HoldablePlugin is currently holded.  
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Config.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public boolean isHolded() {
        return this.holded;
    }

    /**
    Get the orientation that this plugin is set to run with.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Config.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public Orientation getOrientation() {

        //FIX ME:  This was debug code... remove it
        if (this.orientation == null) {
            throw new RuntimeException("ouch... orientation was null");
        }
        //END FIX ME
        return this.orientation;

    }

    /**
    Return the entry that was used to obtain this plugin
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Config.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public PluginHolderEntry getEntry() {
        return this.entry;
    }

    /**
    Used for debuging.  Take the current plugin and dump it to console.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Config.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public void dump() {
        Log.log(Log.MESSAGE, this, "\tPluginHolderConfig: getView:  " + this.getView() );
        Log.log(Log.MESSAGE, this, "\tPluginHolderConfig: isHolded:  " + this.isHolded() );

        //dump the entry
        this.getEntry().dump();

        //dump the orientation
        this.getOrientation().dump();
    }
    
}
