/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder;


//jEdit support
import org.gjt.sp.jedit.View;
import org.gjt.sp.util.Log;

//GUI stuff
import javax.swing.*;
import java.awt.*;

//java stuff
import java.util.Vector;



/**
Handles holding plugins and providing a basic GUI for them.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
*/
public class Container extends JPanel {
    
    private JTabbedPane     tabs            = new JTabbedPane( JTabbedPane.BOTTOM );
    private Orientation     orientation     = null;
    private Vector          plugins         = new Vector();
    private View            view            = null;
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    Container( HoldablePlugin plugin, 
               Orientation orientation,
               View view ) {

        super();

        if ( plugin == null ) {
            throw new IllegalArgumentException("plugin argument may not be null.");
        } else if ( orientation == null ) {
            throw new IllegalArgumentException("orientation argument may not be null.");
        }

        this.view = view;

        this.setLayout( new BorderLayout() );
        this.orientation = orientation;
        this.add( tabs, BorderLayout.CENTER );
        this.addPlugin( plugin );

    }
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void addPlugin(HoldablePlugin plugin) {
        this.plugins.addElement( plugin );
		loadPluginIcon();
        if (pluginIcon != null) {
            this.tabs.addTab( plugin.getConfig().getEntry().getName(),
                pluginIcon, plugin 
            );
        } else {
            this.tabs.addTab( plugin.getConfig().getEntry().getName(), plugin );
        }
    }

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void removePlugin(HoldablePlugin plugin) {
        this.plugins.removeElement( plugin );
        this.tabs.removeTabAt( this.tabs.indexOfTab( plugin.getConfig().getEntry().getName() ) );

    }
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public Orientation getOrientation() {
        return this.orientation;
    }


    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public int getPluginCount() {
        return this.plugins.size();
    }
    

    /**
    Determine what jEdit view this is running under.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public View getView() {
        return this.view;
    }
    
    /**
    Used for debuging.  Take the current plugin and dump it to console.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Container.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void dump() {
        Log.log(Log.DEBUG, this, "getComponentCount: "
			+ this.getComponentCount() );

        //dump the orientation
        this.getOrientation().dump();
    }

    private static ImageIcon pluginIcon = null;

    private static void loadPluginIcon() {
		if (pluginIcon != null) { return; }
        java.net.URL url =Container.class.getResource("/icons/Plugin.gif");
        if (url != null) {
            pluginIcon = new ImageIcon(url);
		}
    }
}
