/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

 
package net.sourceforge.jedit.pluginholder;


//jedit stuff
import org.gjt.sp.jedit.View;

//standard java stuff
import java.util.Vector;
import java.util.Hashtable;



public class ContainerMonitor {


    /**
    Handles View - Container[] maps.  For every view this holds a vector of 
    Containers
    */
    private static Hashtable containerMap = new Hashtable();

    /**
    Add a reference to this container

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: ContainerMonitor.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public static void addContainer( net.sourceforge.jedit.pluginholder.Container container ) {
        
        View view = container.getView();
        
        Vector v = (Vector)ContainerMonitor.containerMap.get( view );
        
        if (v == null) {
            v = new Vector();
            ContainerMonitor.containerMap.put( view, v );
        }

        v.addElement( container );
        
    }

    /**
    Remove a reference to this container

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: ContainerMonitor.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public static void removeContainer( net.sourceforge.jedit.pluginholder.Container container ) {


        View view = container.getView();
        
        Vector v = (Vector)ContainerMonitor.containerMap.get( view );
        
        if (v == null) {
            //if the vector is null then there is no way this can have any elements
            //so don't remove them
            return;
        }

        v.removeElement( container );
        
    }

    /**
    Given a view, return the list of containers it has.  If none are found 
    returns an array of 0 length

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: ContainerMonitor.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public static net.sourceforge.jedit.pluginholder.Container[] getContainers( View view ) {
        
        Vector v = (Vector)ContainerMonitor.containerMap.get( view );
        
        if (v == null) {
            return new net.sourceforge.jedit.pluginholder.Container[0];
        }
        
        net.sourceforge.jedit.pluginholder.Container[] container = new net.sourceforge.jedit.pluginholder.Container[ v.size() ];
        v.copyInto(container);
        return container;

    }


    /**
    Given a View and an orientation... get a container with the given 
    orientation
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: ContainerMonitor.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public static net.sourceforge.jedit.pluginholder.Container getContainer( View view, Orientation orientation ) {
        
        net.sourceforge.jedit.pluginholder.Container[] containers = ContainerMonitor.getContainers( view );
        
        for ( int i = 0; i < containers.length; ++i ) {
            
            if ( containers[i].getOrientation().equals( orientation ) ) {
                return containers[i];
            }
            
        }

        return null;
    }
    
    
    /**
    Return's true if the given View is holding any plugins.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: ContainerMonitor.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public static boolean isHoldingPlugins( View view ) {
 
        Vector v = (Vector)ContainerMonitor.containerMap.get( view );
        
        if (v == null) {
            //if the vector is null then there is no way this can have any elements
            //so don't remove them
            return false;
        }

        if ( v.size() == 0 ) {
            return false;
        } else {
            return true;
        }
        
       
    }

}
