/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

 
package net.sourceforge.jedit.pluginholder; 

import net.sourceforge.jedit.pluginholder.gui.*; 

//required for jEdit use
import org.gjt.sp.jedit.*;


//GUI support
import java.awt.event.*;
import java.awt.*;
import javax.swing.*;

//java stuff
import java.util.Hashtable;


/**
Handles obtain a reference to the current view and then if it has plugins, 
shrinking the or expanding them.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
@version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
*/
public class HideShowPluginsAction extends EditAction {

    private Hashtable splitViewMaps = new Hashtable();
    
    HideShowPluginsAction() {
        // identify prefix to .label property for menu
        super("pluginholder.hideshow");

    }

    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void actionPerformed(ActionEvent evt) {


        View view = EditAction.getView(evt);
        
        SplitViewMap map = this.getSplitViewMap( view );

        if ( map.getExpanded() ) {
            
            this.hide( view, map );
            
        } else {
            this.show( view, map );
            this.show( view, map );
        }
        
        
        //Swing bug... every once and a while.. the JSplitpane will leave a trail
        //across the View... so repaint it so that this will go away.
        view.repaint();
    }

    
    
    
    /**
    Tell jEdit to make this menu a checkbox
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public boolean isToggle() {
        return true;
    }



    /**
    Tells jEdit whether or not the specified plugin should have it's menu 
    item checked or not
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public boolean isSelected(Component comp) {
        return this.hasMap( getView(comp) );
    }
    

    
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    private SplitViewMap getSplitViewMap( View view ) {
        
        SplitViewMap map = (SplitViewMap)this.splitViewMaps.get( view );
        
        if (map == null) {
            map = new SplitViewMap( true );
            this.setSplitViewMap( view, map );
        }
        
        return map;
        
    }


    private boolean hasMap( View view ) {

        SplitViewMap map = (SplitViewMap)this.splitViewMaps.get( view );
        
        if (map == null) {
            return false;
        }

        return map.getExpanded();
        
    }
    
    
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    private void setSplitViewMap( View view,  SplitViewMap map) {
        this.splitViewMaps.put( view, map );       
    }
    

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void show( View view, SplitViewMap map ) {


        this.showHoldableContainer( getHoldableContainer( Orientation.NORTH, view ), map );
        this.showHoldableContainer( getHoldableContainer( Orientation.SOUTH, view ), map );
        this.showHoldableContainer( getHoldableContainer( Orientation.EAST, view ), map );
        this.showHoldableContainer( getHoldableContainer( Orientation.WEST, view ), map );        

        map.setExpanded( true );        
        
    }

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void showHoldableContainer(net.sourceforge.jedit.pluginholder.Container container, SplitViewMap map ) {

        if (container != null) {

            JSplitPane split = (JSplitPane)container.getParent();
    
            int where = container.getOrientation().getWhere();        
            
            int location = map.getLocation( where );
    
            if ( location < split.getMinimumDividerLocation() ) {
                location = split.getMinimumDividerLocation();
            }
            
          
            split.setDividerLocation( location );
    
            //BEGIN HACK
            //This was done so that Swing would realize that the previous split pane
            //was resized
            split.repaint();
            split.setVisible(false);
            split.setEnabled(false);
            split.setVisible(true);
            split.setEnabled(true);
            //END HACK
        }
    

    }
    
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public net.sourceforge.jedit.pluginholder.Container getHoldableContainer(int where, View view) {

        net.sourceforge.jedit.pluginholder.Container[] containers = ContainerMonitor.getContainers( view );

        for ( int i = 0; i < containers.length; ++i ) {
            
            if ( where == containers[i].getOrientation().getWhere() ) {
                return containers[i];
            }
            
        }


        return null;
    }

    /**
    Hide all  plugins within the give view
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void hide( View view, SplitViewMap map ) {

        this.hideHoldableContainer( getHoldableContainer( Orientation.NORTH, view ), map, view );
        this.hideHoldableContainer( getHoldableContainer( Orientation.SOUTH, view ), map, view );
        this.hideHoldableContainer( getHoldableContainer( Orientation.EAST, view ), map, view );
        this.hideHoldableContainer( getHoldableContainer( Orientation.WEST, view ), map, view );        

        map.setExpanded( false );
    }

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void hideHoldableContainer(net.sourceforge.jedit.pluginholder.Container container, SplitViewMap map, View view ) {


        if (container != null) {

            JSplitPane split = (JSplitPane)container.getParent();
            
            int where = container.getOrientation().getWhere();
            
            Dimension dim = view.getSize();
    
            //tell the map where the split was so that when the user shows the 
            //plugins the are back to their original location
    
            switch (where) {
                
                case Orientation.WEST:
                    setDividerLocation( split, 0, Orientation.WEST, map );
                break;
    
                case Orientation.EAST:
                    setDividerLocation( split, dim.width, Orientation.EAST, map );
                break;
    
                case Orientation.NORTH:
                    setDividerLocation( split, 0, Orientation.NORTH, map );
                break;
    
                case Orientation.SOUTH:
                    setDividerLocation( split, dim.height, Orientation.SOUTH, map );
                break;
                
            }
        }
        
        
    }
    
    /**
    Set the location of this split pane...
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    private void setDividerLocation(JSplitPane split, 
                                    int location, 
                                    int where,
                                    SplitViewMap map) {



                                        
        map.setLocation( where, split.getDividerLocation() );
        split.setDividerLocation( location );

    }
    
}


/**
Handles holding views and determining if they are expanded, and their list 
positions.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
@version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
*/
class SplitViewMap {
    
    private boolean expanded = false;
    

    /**
    Holds locations.  Each index is an orientation.
    */
    private int[] locations = { 0, 0, 0, 0 };
    
    
    public SplitViewMap( boolean expanded ) {
        this.expanded = expanded;
    }
    
    /**
    Set the location of the given location.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void setLocation( int orientation, int location ) {
        //make sure this location is valid
        if ( ! Orientation.isValidWhere( orientation ) ) {
            throw new IllegalArgumentException();
        }
        

        
        this.locations[orientation - 1] = location;

    }
    
    /**
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: HideShowPluginsAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public int getLocation( int orientation ) {

        //make sure this location is valid
        if ( ! Orientation.isValidWhere( orientation ) ) {
            throw new IllegalArgumentException();
        }
        
        
        return this.locations[ orientation - 1];
    }

    
    public void setExpanded(boolean expanded) {
        this.expanded = expanded;
    }
    
    public boolean getExpanded() {
        return this.expanded;
    }

    
}
