/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder; 

import net.sourceforge.jedit.pluginholder.backend.*;

import org.gjt.sp.jedit.*;

import javax.swing.*;
import java.awt.Dimension;
import java.util.Vector;

//FIX ME:  Make this class abstract and init abstract... also call to super() should
//be here so that JPanel get's instantiated
 
/**
This is the base class for HoldablePlugins.  Any object that wants to be 
holdable should extend this.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
*/
public class HoldablePlugin extends JPanel implements EBComponent {

    private Config config = null;
    
    /**
    Provide runtime initialization of a HoldablePlugin.  If a developer wishes
    to override and provide his own impl then he must call super.init() because
    getConfig() will not work and it is required for PluginHolder

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public void init(Config config){
        this.config = config;
    }

    /**
    Return the PluginHolderConfig for this plugin.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public final Config getConfig() {
        return this.config;
    }

    final void setConfig(Config config) {
       this.config = config;
    }
    
    /**
    Provide EditBus functionality.

    @see org.gjt.sp.jedit.EBComponent
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public void handleMessage(EBMessage message) { }

    /**
    This is necessary because by default the jsplitpane restricts the panel
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public Dimension getMinimumSize() {

        //return the default if the config is null
        if (this.getConfig() == null) {
            super.getMinimumSize();
        }

        return new Dimension( 0, 0 );


    }
 
    /**
    Requires that only one instance of this HoldablePlugin is allowed to run 
    in each view... IE this plugins "stands alone" in each view.

    @deprecated Use a custom PluginHolderEntry instead.  You should call 
    setRequiredStandalone(true) if you want this behavior.
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public boolean isRequiredStandalone() {
        return false;
    }
   
    /**
    Get the actions that this Plugin is supposed to register...
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public static final void addPluginHolderAction( PluginHolderAction action ) {

        ActionStore.addPluginHolderAction( action );

    }

    /**
    Return the actiosn registered for this plugin.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public final PluginHolderAction[] getPluginHolderActions() {
        
        return ActionStore.getPluginHolderActions( this.getClass().getName() );
   
    }
    
    /**

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public void requestFocus() {
        super.requestFocus();

        if (this.getParent() instanceof javax.swing.JTabbedPane) {
            
            javax.swing.JTabbedPane tabs = (javax.swing.JTabbedPane)this.getParent();
            tabs.setSelectedComponent( this );
        }

    }

    
   /**
    Used for debuging.  Take the current plugin and dump it to console.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldablePlugin.java,v 1.8 2000/04/24 06:29:51 burtonator Exp $
    */
    public void dump() {

        this.getConfig().dump();
        
    }

}
