/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

 
package net.sourceforge.jedit.pluginholder; 


//jEdit support
import org.gjt.sp.jedit.GUIUtilities;
import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.util.Log;

//GUI support
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


/**
Handles detached HoldablePlugin(s) and manages their geometry.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: HoldableWindow.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
*/
public class HoldableWindow extends JFrame implements WindowListener {
    
    private HoldablePlugin plugin = null;


    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldableWindow.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    HoldableWindow(HoldablePlugin plugin) {

        super( getRootEntryName( plugin ) );
        
        this.plugin = plugin;
        
        this.loadGeometry();
        
        
        this.getContentPane().setLayout( new BorderLayout() );

        this.getContentPane().add( plugin );

        this.addWindowListener( this );
        this.setEnabled(true);
        this.setVisible(true);
        this.show();
        this.toFront();

        
    }

    /**
    Given a Plugin, determine what the root name is.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldableWindow.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public static String getRootEntryName( HoldablePlugin plugin ) {
        String name = "";
        PluginHolderEntry entry =  plugin.getConfig().getEntry();
        
        if ( entry.isChildMenuItem() ) {
            return entry.getParent().getName();
        } else {
            return entry.getName();
        }
        
    }
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldableWindow.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    private void loadGeometry() {
        Log.log(Log.MESSAGE, this, "loading geometry....");
        this.requireGeometry();
        GUIUtilities.loadGeometry( this, plugin.getConfig().getEntry().getLabel() );
        //frame.setSize( new Dimension(350, 600) );
    }


    /**
    If jEdit doesn't have any geometry entries then make sure they exist
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldableWindow.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    private void requireGeometry() {
    
        String label = this.plugin.getConfig().getEntry().getLabel();

        this.requireProperty( label + ".width",  "350" );
        this.requireProperty( label + ".height", "600" );
        this.requireProperty( label + ".x",  "0" );
        this.requireProperty( label + ".y",  "0" );
        
        
    }
    
    /**
    If the given property doesnt exist.. then set if the the given value
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: HoldableWindow.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    private void requireProperty(String prop, String value) {
        
        if ( jEdit.getProperty(prop) == null ) {
            
            jEdit.setProperty( prop, value );
            
        }
        
    }
    
    
    //WindowListener interface...
    
    public void windowActivated(WindowEvent e) {}
        
    public void windowClosed(WindowEvent e) {}
    
    public void windowClosing(WindowEvent e) {

        Log.log(Log.MESSAGE, this, "saving geometry");
        GUIUtilities.saveGeometry( this, plugin.getConfig().getEntry().getLabel() );
        

        this.dispose();


    }

    public void windowDeactivated(WindowEvent e) {} 

    public void windowDeiconified(WindowEvent e) {} 

    public void windowIconified(WindowEvent e) {}

    public void windowOpened(WindowEvent e) {}


}
