/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder;

import org.gjt.sp.util.Log;

public class Orientation {


    public final static int NORTH           = 1;
    public final static int SOUTH           = 2;    
    public final static int EAST            = 3;
    public final static int WEST            = 4;    
    public final static int DEFAULT_DEGREE  = 0;
    
    
    private int where = 0;
    private int degree = 0;    

    public Orientation( int where, int degree) {


        this.setWhere(where);
        this.degree = degree;
        
    }

    
    public int getWhere() {
        return this.where;
    }

    public int getDegree() {
        return this.degree;
    }

    void setWhere(int where) {
        if (where != NORTH && where != SOUTH && where != EAST && where != WEST) {
            throw new IllegalArgumentException();
        }
        this.where = where;
    }
    

    /**
    Compare this to another orientation
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Orientation.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public boolean equals(Object obj) {
        if ( ! (obj instanceof Orientation) ) {
            return false;
        }
        
        Orientation orientation = (Orientation)obj;
        return  this.getWhere() == orientation.getWhere() && 
                this.getDegree() == orientation.getDegree();
        
    }

    /**
    Returns true if the given where is in N,E,W,S
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Orientation.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public static boolean isValidWhere(int where) {
        
        return where == Orientation.NORTH || 
               where == Orientation.EAST ||
               where == Orientation.WEST ||
               where == Orientation.SOUTH;
        
    }
    
    /**
    Used for debuging.  Take the current plugin and dump it to console.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Orientation.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void dump() {
        Log.log(Log.DEBUG, this, "getWhere:  " + this.getWhere() );
        Log.log(Log.DEBUG, this, "getDegree: " + this.getDegree() );
    }

    
}

