/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder;


//standard java stuff
import java.util.Vector;
import java.awt.BorderLayout;

//jedit support
import org.gjt.sp.jedit.*;


/**
Handles creating references to Plugins

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: PluginFactory.java,v 1.4 2000/04/27 07:11:27 burtonator Exp $
*/
public class PluginFactory {
    
    /**
    Get a plugin but default to it not being holded
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginFactory.java,v 1.4 2000/04/27 07:11:27 burtonator Exp $
    */
    public final static HoldablePlugin getPlugin( PluginHolderEntry entry, 
                                                  View view ) 
        throws InstantiationException {

        return getPlugin( entry, view, false );
    }
    
    
    /**
    Takes care of constructing the plugin and then returns it.  This is the 
    factory used to obtain all plugins.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginFactory.java,v 1.4 2000/04/27 07:11:27 burtonator Exp $
    */
    public final static HoldablePlugin getPlugin( PluginHolderEntry entry, 
                                                  View view, 
                                                  boolean holded ) 
        throws InstantiationException {
        
        HoldablePlugin plugin;
        
        try {

            plugin = (HoldablePlugin)Class.forName( entry.getClassName() ).newInstance();

        } catch (Exception e) {
            e.printStackTrace();
            throw new InstantiationException( e.getMessage() );
        }
        
        
        Config initConfig = new Config( view, holded, entry, getOrientation( plugin ) );
        
        //this gaurantees that the plugin can always get it's config
        plugin.setConfig( initConfig );


        //make sure that all plugins have at least one layout defined... provide
        //the basic one here and if plugins want to define their own with init() 
        //they can
        
        plugin.setLayout( new BorderLayout() );
        
        plugin.init( initConfig );

        EditBus.addToBus( plugin );
        
        return plugin;
        
    }
    
    /**
    Resolve the classname... then construct the plugin and return it.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginFactory.java,v 1.4 2000/04/27 07:11:27 burtonator Exp $
    */
    public final static HoldablePlugin getPlugin( String classname,
                                                  View view, 
                                                  boolean holded ) 
        throws InstantiationException {
            
        //get the plugin
        
        PluginHolderEntry entry = null;
        PluginHolderEntry[] entries = PluginHolder.getPlugins();
        
        for (int i = 0; i < entries.length; ++i) {
            if ( entries[i].getClassName().equals(classname) ) {
                entry = entries[i];
            }
        }
        
        if (entry == null) {
            throw new InstantiationException( "The plugin class you specified was not found:  " + classname );
        }
        
        
        return getPlugin( entry, view, holded );
        
    }

    /**
    Given a plugin, get its orientation

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginFactory.java,v 1.4 2000/04/27 07:11:27 burtonator Exp $
    */
    //TODO: add support for profiles.
    private static Orientation getOrientation(HoldablePlugin plugin) {

        return new Orientation( Orientation.EAST, 
                                Orientation.DEFAULT_DEGREE );

    }

    
}
