/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder; 

//plugin holder stuff
import net.sourceforge.jedit.pluginholder.backend.*;
import net.sourceforge.jedit.pluginholder.msg.*;

//jedit support
import org.gjt.sp.jedit.*;
import org.gjt.sp.util.Log;

//java support
import java.awt.event.ActionEvent;

/**
This is an action used to register this Plugin.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
@version $Id: PluginHolderAction.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
*/
public class PluginHolderAction extends EditAction {


    private PluginHolderEntry   entry = null;
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: PluginHolderAction.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public PluginHolderAction( PluginHolderEntry entry ) {
        // identify prefix to .label property for menu

        super( entry.getLabel() );
        this.entry = entry;

    }

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: PluginHolderAction.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public PluginHolderAction( String classname, String label ) {
        this( new PluginHolderEntry( classname, label ) );
    }

    
    
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: PluginHolderAction.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public void actionPerformed( ActionEvent evt ) {

        HoldablePlugin plugin = null;

        //get the reference to this plugin for the given view.
        View view = EditAction.getView(evt);
        
        //if this plugin is stand alone...
        if ( this.getEntry().isRequiredStandalone() ) {

            Log.log(Log.WARNING, this, 
				"this plugin must run in a standalone state" );
            //bring this component to the top of the plugins list. even 
            //if it is docked and within a JTabbedPane

            //see if the plugin is already running within the current view as 
            //swallowed

            try {

                PluginHolderEntry entry = null;
                
                if ( this.getEntry().getParent() != null ) {
                    entry = this.getEntry().getParent();
                } else {
                    entry = this.getEntry();
                }
                
                plugin = ProfileFactory.getCurrentProfile().getPlugin( entry, view );

                //at this point PluginNotFoundException should be thrown or this
                //plugin is already running as holded so it should be OK to send 
                //an EditBus message that this is getting built.
                EditBus.send( new EntrySelectedMessage( plugin, entry ) );
                
            } catch ( PluginNotFoundException e ) {
                //at this point plugin holder didnt' run this as swallowed so we need 
                //to instantiate it and then place it in the StandalonePluginMapper
                
                plugin = StandalonePluginMapper.getPlugin( this.getEntry(), view );
                
                //if the plugin is null here this means that it wasn't created and
                //you need to instantiate the plugin and place it back into
                //the mapl
                if ( plugin == null ) {
                    try {
                        plugin = PluginFactory.getPlugin( this.getEntry(), view );
                    } catch (InstantiationException f) {
                        //this is bad and we can't recover here...
                        e.printStackTrace();
                        return;
                    }

                    StandalonePluginMapper.addPlugin( plugin, view );
                    new HoldableWindow( plugin );
                }
                
                
            }
            
            
            plugin.requestFocus();
            
            return;
            
        }
    
    
    
        //the plugin isn't standalone so instantiate it and bring up a window
        try {
            plugin = PluginFactory.getPlugin( this.getEntry(), view );
        } catch (InstantiationException e) {
            //this is bad and we can't recover here...
            e.printStackTrace();
            return;
        }
    
        new HoldableWindow( plugin );


    }

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: PluginHolderAction.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public PluginHolderEntry getEntry() {
        return this.entry;
    }
    
} 

