/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

 
package net.sourceforge.jedit.pluginholder; 

//the standard swing stuff
import javax.swing.*;
import javax.swing.tree.*;

//awt stuff for swing support
import java.awt.*;


import java.awt.event.*;  // required for KeyListener and ActionListener
import javax.swing.event.*;


//required for jEdit use
import org.gjt.sp.jedit.*;
import org.gjt.sp.jedit.gui.*;
import org.gjt.sp.jedit.msg.*;
import org.gjt.sp.util.*;

import java.util.Vector;
import java.util.Hashtable;

//plugin holder support
import net.sourceforge.jedit.pluginholder.gui.*;
import net.sourceforge.jedit.pluginholder.backend.*; 

public class PluginHolderPlugin extends EBPlugin {


    Vector menus = null;
    Vector menuItems = null;
    
    /**
    Tells jEdit how to load ProjectViewer

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
	public void createMenuItems(View view, Vector menus, Vector menuItems) {

        this.menus = menus;
        this.menuItems = menuItems;
        
		//menuItems.addElement( GUIUtilities.loadMenuItem(view, "pluginholder.open") );

        
        menus.addElement( GUIUtilities.loadMenu(view, "pluginholder-menu") );


        PluginHolder.dump();
        
        //now add all known plugins... so that they can be created "detached" 
        //by the user
        PluginHolderEntry[] plugins = PluginHolder.getPlugins();
    
        //NOTE:  it is important that you load the child menu items before you
        //load any menus.  This is required for jEdit to realized that an action
        //exists
        this.loadChildMenuItems( plugins, view );
        this.loadMenus( plugins, view );
        this.loadMenuItems( plugins, view );

	}


    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    private void loadMenuItems( PluginHolderEntry[] plugins, View view ) {

        //load the plain plugins

        for (int i = 0; i < plugins.length; ++i) {

            if ( plugins[i].isMenuItem() ) {

         		menuItems.addElement( GUIUtilities.loadMenuItem( view, plugins[i].getLabel() ) );
                
            } 
        }

        
    }

    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    private void loadMenus( PluginHolderEntry[] plugins, View view ) {

        //load all the menus
        for (int i = 0; i < plugins.length; ++i) {

            if ( plugins[i].isMenu() ) {

                Log.log( Log.DEBUG, "PluginHolder", "Loading plugin menu: "+ plugins[i].toString() );                
                menus.addElement( GUIUtilities.loadMenu( view, plugins[i].getLabel() ) );

            } 
            
        }

        
    }
    
    /**
    Handles creating actions for MenuItems
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    private void loadChildMenuItems( PluginHolderEntry[] plugins, View view ) {

        for (int i = 0; i < plugins.length; ++i) {

            if ( plugins[i].isChildMenuItem() ) {

                Log.log( Log.DEBUG, "PluginHolder", "Loading plugin menuitem: "+ plugins[i].toString() );
                
                PluginHolderAction action = new PluginHolderAction( plugins[i] );
            
                jEdit.addAction( action );
                
                ActionStore.addPluginHolderAction( action );
             
            }

        }
        
    }
    
    
    /**
    Start the plugin

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public void start() {

        Log.log( Log.DEBUG, this, "PluginHolder start()" );
        
        jEdit.addAction( new ToggleHoldableAction() );
        jEdit.addAction( new HideShowPluginsAction() );

        ProfileFactory.parse();

    }

    /**
    When stoping the plugin... save the config.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public void stop() {

        ProfileFactory.save();
        
    }

    public void createOptionPanes(OptionsDialog od) {
        od.addOptionPane( new OptionsPanel()  );
    }


    /**
    Provide EditBus functionality.

    @see org.gjt.sp.jedit.EBComponent
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginHolderPlugin.java,v 1.9 2000/07/10 03:11:59 akaplan Exp $
    */
    public void handleMessage(EBMessage message) {

        if ( message instanceof ViewUpdate ) {

            ViewUpdate vu = (ViewUpdate)message;
            
            if ( vu.getWhat().equals( ViewUpdate.CREATED ) ) {
                
                
                //future use..  if the user has asked to launch PluginHolder
                //on view creating then do so here.

            }
        }
    }
    
    
    
}
    
    

