/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

 
package net.sourceforge.jedit.pluginholder; 

//required for jEdit use
import org.gjt.sp.jedit.*;
import org.gjt.sp.util.Log;

//GUI support
import java.awt.event.*;
import java.awt.*;


/**
Class used to enable-disable plugins within the current view.


@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
@version $Id: ToggleHoldableAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
*/
public class ToggleHoldableAction extends EditAction {


    /**
    Used to toggle viewing of plugins.
    */
    private boolean hold = false;
    
    ToggleHoldableAction() {
        // identify prefix to .label property for menu
        super("pluginholder.open");

    }

    /**

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: ToggleHoldableAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public void actionPerformed(ActionEvent evt) {

        //figure out which plugins I need to run here...
        //new ProjectViewer( false, EditAction.getView(evt) );

        View view = EditAction.getView(evt);

        this.toggleView( view );

        
        HoldablePlugin plugin;

        /*
        PluginHolder.addPlugins( view, profile.getEntries( 
            new Orientation( Orientation.WEST, Orientation.DEFAULT_DEGREE ) ) );
        */


        Profile profile = ProfileFactory.getCurrentProfile();
        

        //figure out whether we should start plugin viewer or stop it
        if ( this.hold ) {

            Log.log(Log.DEBUG, this, "adding plugins" );
            PluginHolder.addPlugins( view, profile );

        } else {

            Log.log(Log.DEBUG, this, "removing plugins" );
            PluginHolder.removePlugins( view );

        }
        


    }

    /**
    Tell jEdit to make this menu a checkbox
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: ToggleHoldableAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public boolean isToggle() {
        return true;
    }

    /**
    Tells jEdit whether or not the specified plugin should have it's menu 
    item checked or not
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>    
    @version $Id: ToggleHoldableAction.java,v 1.3 2000/07/10 03:11:59 akaplan Exp $
    */
    public boolean isSelected(Component comp) {
        View v = getView(comp);
        return ContainerMonitor.isHoldingPlugins( v );
    }
    

    private void toggleView(View view) {

        if (this.hold == true) {
            this.hold = false;
        } else {
            this.hold = true;
        }

    }
    
} 

