/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder.backend; 


//plugin holder support
import net.sourceforge.jedit.pluginholder.*; 

//jedit...
import org.gjt.sp.jedit.*;

//standard java stuff
import java.util.*;


/**
<p>
The StandalonePluginMapper is a static class that handles mapping views to 
instantiated plugins.  It is singleton based and can only be used for standalone
plugins
</p>

<p>
The map is setup like this: 
    <pre>
            View -> Entry -> plugin.
    </pre>
</p>

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: StandalonePluginMapper.java,v 1.1 2000/04/24 06:29:51 burtonator Exp $
*/
public class StandalonePluginMapper {
    
    /**
    This holds the available views
    */
    private static Hashtable viewMap = new Hashtable();
    
    /**
    Add a plugin to the view map.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: StandalonePluginMapper.java,v 1.1 2000/04/24 06:29:51 burtonator Exp $
    */
    public static void addPlugin( HoldablePlugin plugin, 
                                  View view ) {

        if ( plugin.getConfig().getEntry().isRequiredStandalone() == false ) {
            throw new RuntimeException( "You can only add standalone plugins here." );
        }

        StandalonePluginMapper.getPluginMap( view )
            .put( plugin.getConfig().getEntry(), plugin );

    }
    
    private static Hashtable getPluginMap( View view ) {
        
        Hashtable pluginMap = (Hashtable)viewMap.get(view);
        
        if ( pluginMap == null ) {
            pluginMap = new Hashtable();
            StandalonePluginMapper.viewMap.put( view, pluginMap );
        }
        
        return pluginMap;
    }
    
    
    /**
    Given an entry and a view, get the entered Plugin.  Will return null if one
    is not entered.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: StandalonePluginMapper.java,v 1.1 2000/04/24 06:29:51 burtonator Exp $
    */
    public static HoldablePlugin getPlugin( PluginHolderEntry entry,
                                            View view ) {
        
        HoldablePlugin plugin = null;
        
        plugin = (HoldablePlugin)StandalonePluginMapper.getPluginMap( view )
            .get( entry );
        
        return plugin;
    }
    
}
