/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder.gui;


//jedit support
import org.gjt.sp.jedit.*;

import org.gjt.sp.util.Log;

//GUI support
import javax.swing.*;
import javax.swing.table.*;
import java.awt.*;

//java stuff
import java.util.Vector;

//plugin holder support
import net.sourceforge.jedit.pluginholder.*;


/**
Provides a GUI for configuring which plugins you want to view and where you 
want to view them.

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: OptionsPanel.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
*/
public class OptionsPanel extends AbstractOptionPane {

    private JTable      plugins     = null;
    private JLabel      status      = new JLabel(" ");
    private JComboBox   profiles    = new JComboBox();
    private PluginTable table       = new PluginTable();
    
    
    /**
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: OptionsPanel.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public OptionsPanel() {
        
        super( "pluginholder" );
	}
	
	public void _init() {
        //get the plugins for the current view.

        Profile[] profiles = ProfileFactory.getProfiles();
        
        //FIX ME:  right now just do the first profile.

        if ( profiles.length > 0 ) {
            
            this.profiles.addItem( profiles[0] );
            
            PluginHolderEntry[] entries = profiles[0].getEntries();
            
            //this.plugins = new JTable( entries, names );
            
        }
        
        // this.setLayout( new BorderLayout() );

        JPanel misc = new JPanel();
        misc.setBorder( BorderFactory.createTitledBorder( 
            jEdit.getProperty( "options.pluginholder.description.label" ) ) );

        misc.setLayout( new BorderLayout() );

        //misc.add( getBar(), BorderLayout.NORTH );
        misc.add( new JScrollPane( this.getPluginTable() ) , BorderLayout.CENTER );
        misc.add( this.status, BorderLayout.SOUTH );
        
        addComponent(misc);
        
        //this.setEnabled(true);
        //this.setVisible(true);
            
    }

    /**
    Get an initialzed JTable that contains all the plugins that the user can 
    dock.

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: OptionsPanel.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    private JTable getPluginTable() {
        return this.table;
    }

    /**
    Returns the top bar of the option pane.
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: OptionsPanel.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    private JPanel getBar() {

        JPanel bar = new JPanel();
        BorderLayout layout = new BorderLayout();
        layout.setHgap( 5 );

        bar.setLayout( layout );

        bar.add( new JLabel( jEdit.getProperty("options.pluginholder.profiles.label") ), BorderLayout.WEST );
        bar.add( this.profiles, BorderLayout.CENTER );

        return bar;
    }


    /**
    Save the new Profile options
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: OptionsPanel.java,v 1.4 2000/07/10 03:11:59 akaplan Exp $
    */
    public void _save() {

        Log.log(Log.MESSAGE, this, "Plugin Holder: saving options");

        PluginTableModel model = (PluginTableModel)this.table.getModel();

        int end = model.getRowCount();
        
        PluginHolderEntry[] entries = PluginHolder.getPlugins();

        Profile prof = ProfileFactory.getCurrentProfile();
        
        prof.removeAll();

        for (int i = 0; i < end; ++i) {
            
            Boolean shouldEnable =  (Boolean)model.getValueAt( i, 0 );
            String  where = (String)model.getValueAt( i, 1 );
            
            
            
            if ( shouldEnable.booleanValue() == true ) {
                Log.log(Log.MESSAGE, this, "PluginHolder:  Enabling plugin: " 
					+ entries[i].getClassName() );

                
                EntryOrientationMap map = new EntryOrientationMap( entries[i],
                                                                   new Orientation( Where.getWhere( where ),
                                                                                    Orientation.DEFAULT_DEGREE ) );
                                                                                  
                prof.addEntryOrientationMap( map );

            } 

        }
        
        
        ProfileFactory.save();
        
    }
    
    
    
}

