/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder.gui;

//GUI support
import javax.swing.*;
import javax.swing.table.*;
import java.awt.*;

import net.sourceforge.jedit.pluginholder.*;


/**
Abstracts rendering of the JTable so that Plugin Entries are pre-populated

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: PluginTable.java,v 1.1.1.1 2000/01/17 04:03:05 burtonator Exp $
*/
public class PluginTable extends JTable {

    private boolean DEBUG = true;

    public final static int ROW_HEIGHT = 20;

    public final static int COLUMN_ZERO_WIDTH = 60;
    public final static int COLUMN_ONE_WIDTH  = 75;    
    
    /**
    Create a PluginTable and setup column sized and JComboBoxes
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginTable.java,v 1.1.1.1 2000/01/17 04:03:05 burtonator Exp $
    */
    public PluginTable() {
        super( new PluginTableModel() );

        this.setRowHeight( ROW_HEIGHT );

        this.setAutoResizeMode( JTable.AUTO_RESIZE_LAST_COLUMN );
        
        //Set up column sizes.
        initColumnSizes();


        setUpComboColumn(this.getColumnModel().getColumn(1));
        
    }


    private void initColumnSizes() {

        int width = this.getColumnModel().getColumn(0).getWidth() +
                    this.getColumnModel().getColumn(1).getWidth() +
                    this.getColumnModel().getColumn(2).getWidth();

        this.getColumnModel().getColumn(0).setMinWidth( COLUMN_ZERO_WIDTH );
        this.getColumnModel().getColumn(0).setMaxWidth( COLUMN_ZERO_WIDTH );
        this.getColumnModel().getColumn(1).setMinWidth( COLUMN_ONE_WIDTH );
        this.getColumnModel().getColumn(1).setMaxWidth( COLUMN_ONE_WIDTH );



        
        this.getColumnModel().getColumn(2).setPreferredWidth( width );

        
    } 

    public void setUpComboColumn(TableColumn sportColumn) {


        //Set up the editor for the sport cells.
        JComboBox comboBox = new JComboBox();

        Where[] where = Where.getLocations();

        for (int i = 0; i < where.length; ++i) {
            comboBox.addItem( where[i].toString() );            
            
        }
        
        
        sportColumn.setCellEditor(new DefaultCellEditor(comboBox));

        //Set up tool tips for the sport cells.
        DefaultTableCellRenderer renderer =
                new DefaultTableCellRenderer();
        renderer.setToolTipText("Click for combo box");
        sportColumn.setCellRenderer(renderer);

        //Set up tool tip for the sport column header.
        TableCellRenderer headerRenderer = sportColumn.getHeaderRenderer();
        if (headerRenderer instanceof DefaultTableCellRenderer) {
            ((DefaultTableCellRenderer)headerRenderer).setToolTipText(
                     "Click to see a list of choices");
        } 
    }



}
