/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder.gui;

import org.gjt.sp.util.Log;

//GUI support
import javax.swing.*;
import javax.swing.table.*;
import java.awt.*;

//java support
import java.util.Vector;

import net.sourceforge.jedit.pluginholder.*;


public class PluginTableModel extends DefaultTableModel {

    private boolean DEBUG = true;

                                        
    /**
    Create a PluginTableModel with the correct values setup...    
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginTableModel.java,v 1.5 2000/07/10 03:12:00 akaplan Exp $
    */
    public PluginTableModel() {
        super( getTableData(), getColumnNames() );
    }

    
    public Class getColumnClass(int c) {
        return getValueAt(0, c).getClass();
    }

    /*
     * Don't need to implement this method unless your table's
     * editable.
     */
    public boolean isCellEditable(int row, int col) {
        //Note that the data/cell address is constant,
        //no matter where the cell appears onscreen.
        if (col < 2) { 
            return true;
        } else {
            return false;
        }
    }


    /**
    Get the table data that you want rendered into the JTable
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginTableModel.java,v 1.5 2000/07/10 03:12:00 akaplan Exp $
    */
    private static Vector getTableData() {

        Vector rows = new Vector();

        Profile prof = ProfileFactory.getCurrentProfile();
        
        PluginHolderEntry[] entries = PluginHolder.getPlugins();


        for (int i = 0; i < entries.length; ++i) {
            
            if ( entries[i].isMenu() || entries[i].isMenuItem() ) {
            
                Vector row = new Vector();
                row.addElement( new Boolean( prof.hasEntry( entries[i] ) ) );
    
                Log.log(Log.MESSAGE, PluginTableModel.class,
					  "PluginHolder: table... adding where of: "
					+ prof.getOrientation( entries[i] ).getWhere() );
                row.addElement( Where.getWhereAsString( prof.getOrientation( entries[i] ).getWhere() ) );
      
                row.addElement( entries[i].getName() );
                rows.addElement( row );

            }
        }

        
        return rows;
    }

    
    
    
    /**
    Get the 
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: PluginTableModel.java,v 1.5 2000/07/10 03:12:00 akaplan Exp $
    */
    private static Vector getColumnNames() {

        Vector names = new Vector();
        names.addElement("Enable");
        names.addElement("Location");
        names.addElement("Plugin");
        return names;
    }


}

