/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package net.sourceforge.jedit.pluginholder.gui;


import net.sourceforge.jedit.pluginholder.*; 

/**
Used by the JTable to determine where to map this object.  It returns an 
array of Where objects which return a string of an appropriate type

@author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
@version $Id: Where.java,v 1.2 2000/02/01 04:31:17 burtonator Exp $
*/
public class Where {
    
    private int where   = 0;
    private int degree  = 0;

    private static Where[] locations = {
                                       new Where( Orientation.NORTH, 0),
                                       new Where( Orientation.EAST, 0),
                                       new Where( Orientation.WEST, 0),
                                       new Where( Orientation.SOUTH, 0) 
                                       };

    
    private Where(int where, int degree) {
        this.where = where;
        this.degree = degree;
    }
    
    public String toString() {

        return Where.getWhereAsString( this.getWhere() );
        
    }

    public int getWhere() {
        return this.where;
    }

    public int getDegree() {
        return this.degree;
    }

    /**
    Return the different locations where you can run plugins

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Where.java,v 1.2 2000/02/01 04:31:17 burtonator Exp $
    */
    public static Where[] getLocations() {
        return Where.locations;
    }

    /**
    Given an int... return a string representation of it
    
    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Where.java,v 1.2 2000/02/01 04:31:17 burtonator Exp $
    */
    public static String getWhereAsString(int where) {

        switch ( where ) {
            
            case Orientation.NORTH:
                return "Top";
            case Orientation.EAST:
                return "Right";
            case Orientation.WEST:
                return "Left";
            case Orientation.SOUTH:
                return "Bottom";

            default:
                return "Right";
        }

        
    }

    /**
    Given a string... return its ordinal where location

    @author <A HREF="mailto:burton@relativity.yi.org">Kevin A. Burton</A>
    @version $Id: Where.java,v 1.2 2000/02/01 04:31:17 burtonator Exp $
    */
    public static int getWhere(String where) {

        
        if ( where.equals("Top") ) {
            return Orientation.NORTH;
        } else if ( where.equals("Right") ) {
            return Orientation.EAST;
        } else if ( where.equals("Left") ) {
            return Orientation.WEST;
        } else if ( where.equals("Bottom") ) {
            return Orientation.SOUTH;
        } else {
            return Orientation.EAST;
        }
        
    }
    
}

